@@ -53,6 +53,7 @@
 *	V01.22	JRR	30-Mar-1994	Ranking Compute servers.
 *	V01.23	JRR	11-Oct-1994	Version 3.36.1
 * 	V01.24  SLH	21-Nov-1994	Version 3.36.4
+ * 	V01.25	SLH	21-Feb-1995	Version 3.36.7
 */
 /*++ nqs.h - Network Queueing System
  *
@@ -336,6 +337,17 @@
  *
  *
  */
+
+/*
+ * I've had a number of queries which turned out to be due to 
+ * using a non-ANIS C compiler.  So, if the user is trying to use
+ * such a compiler, the following line should happily blowup on them.
+ */
+
+#ifndef __STDC__
+  Please use an ANSI C compiler, such as GNU C.
+#endif
+
 #define	ALIGNTYPE	long		/* Machine-alignment type */
 #include "ioblksiz.h"			/* See warning #1 */
 #if	BSD43 | ULTRIX | DECOSF		/* Berkeley UNIX and ULTRIX */
@@ -435,6 +447,10 @@
 #include 	<stdio.h>
 #include	"nmap.h"			/* Network mapping definitions */
 #include	"quolim.h"		/* Quota limit definitions */
+#include	<sys/file.h>
+#if     IRIX6
+#include        <malloc.h>
+#endif
 
 /*
  *	More configurable parameters.
@@ -1061,7 +1077,7 @@ BAD SYSTEM TYPE
 /*
  *      Additions for NAS NQS
  */
-#define NQS_VERSION "3.36.6"               /* version number for NQS */
+#define NQS_VERSION "3.37.0"               /* version number for NQS */
 #define SUCCESS 0
 #define FAILURE -1
 /*
