@@ -108,8 +108,7 @@
  *		It is assumed that the forms do not already
  *		exist in the forms database.
  */
-void udb_addfor (forms)
-register char *forms;			/* Forms name to be added */
+void udb_addfor (char *forms)
 {
 	struct gendescr newdescr;
 
@@ -129,10 +128,10 @@ register char *forms;			/* Forms name to be added */
  *		is not already present in the NQS manager
  *		access set.
  */
-void udb_addnqsman (account_uid, account_mid, privilege_bits)
-uid_t account_uid;			/* Manager account user-id */
-Mid_t account_mid;			/* Manager account machine-id */
-int privilege_bits;			/* Privilege bits */
+void udb_addnqsman (
+	uid_t account_uid,		/* Manager account user-id */
+	Mid_t account_mid,		/* Manager account machine-id */
+	int privilege_bits)		/* Privilege bits */
 {
 	struct gendescr newdescr;
 
@@ -149,12 +148,12 @@ int privilege_bits;			/* Privilege bits */
  *	void udb_addquedes():
  *	Add a pipe queue destination to the NQS database.
  */
-void udb_addquedes (queue, map)
-struct nqsqueue *queue;			/* Ptr to local queue */
-struct qdestmap *map;			/* Queue/destination map */
+void udb_addquedes (
+	struct nqsqueue *queue,		/* Ptr to local queue */
+	struct qdestmap *map)		/* Queue/destination map */
 {
 	struct gendescr descr;
-	register struct pipeto *pipeto;	/* Destination */
+	struct pipeto *pipeto;	/* Destination */
 
 	pipeto = map->pipeto;
 	descr.v.map.qtodevmap = 0;	/* Queue/destination mapping */
@@ -171,8 +170,7 @@ struct qdestmap *map;			/* Queue/destination map */
  *      void udb_crecom():
  *      Create a queue complex.
  */
-void udb_crecom (qcomplex)
-struct qcomplex *qcomplex;              /* Ptr to queue complex structure */
+void udb_crecom (struct qcomplex *qcomplex)
 {
         struct gendescr descr;
 
@@ -190,8 +188,7 @@ struct qcomplex *qcomplex;              /* Ptr to queue complex structure */
  *	void udb_addquedev():
  *	Add a queue/device mapping to the NQS database.
  */
-void udb_addquedev (map)
-struct qdevmap *map;		/* Queue to device and vice versa map */
+void udb_addquedev (struct qdevmap *map)
 {
 	struct gendescr descr;
 
@@ -208,8 +205,7 @@ struct qdevmap *map;		/* Queue to device and vice versa map */
  *	void udb_credes():
  *	Add a queue destination descriptor to the NQS database.
  */
-void udb_credes (dest)
-struct pipeto *dest;			/* Pipe queue destination structure */
+void udb_credes (struct pipeto *dest)
 {
 	struct gendescr descr;
 
@@ -229,8 +225,7 @@ struct pipeto *dest;			/* Pipe queue destination structure */
  *	void udb_credev():
  *	Add a device to the NQS database.
  */
-void udb_credev (device)
-struct device *device;			/* Device structure */
+void udb_credev (struct device *device)
 {
 	struct gendescr descr;
 
@@ -255,14 +250,13 @@ struct device *device;			/* Device structure */
  *	void udb_creque():
  *	Add a queue to the NQS database.
  */
-void udb_creque (queue)
-struct nqsqueue *queue;			/* Queue structure */
+void udb_creque (struct nqsqueue *queue)
 {
 /*
  *	Uncomment the declaration of: i, if your compiler is not capable
  *	of assigning entire structures.
  *
- *	register int i;
+ *	int i;
  */
 	struct gendescr descr;
 
@@ -379,8 +373,7 @@ struct nqsqueue *queue;			/* Queue structure */
  *      void udb_delcom():
  *      Delete a queue complex.
  */
-void udb_delcom (qcomplex)
-struct qcomplex *qcomplex;              /* Ptr to queue complex structure */
+void udb_delcom (struct qcomplex *qcomplex)
 {
         freedb (Qcomplexfile, qcomplex->qcomplexno);
 }
@@ -392,8 +385,7 @@ struct qcomplex *qcomplex;              /* Ptr to queue complex structure */
  *	void udb_deldes():
  *	Delete a queue destination descriptor from the NQS database.
  */
-void udb_deldes (dest)
-struct pipeto *dest;			/* Pipe queue destination structure */
+void udb_deldes (struct pipeto *dest)
 {
 	freedb (Pipeqfile, dest->pipetono);
 }
@@ -405,8 +397,7 @@ struct pipeto *dest;			/* Pipe queue destination structure */
  *	void udb_deldev():
  *	Delete a device descriptor from the NQS database.
  */
-void udb_deldev (device)
-struct device *device;			/* Device to be deleted */
+void udb_deldev (struct device *device)
 {
 	freedb (Devicefile, device->deviceno);
 }
@@ -419,10 +410,9 @@ struct device *device;			/* Device to be deleted */
  *	void udb_delfor():
  *	Delete a form from the NQS forms database.
  */
-void udb_delfor (forms)
-char *forms;				/* Forms to be deleted */
+void udb_delfor (char *forms)
 {
-	register struct gendescr *descr;
+	struct gendescr *descr;
 
 	seekdbb (Formsfile, 0L);	/* Seek to the beginning of the NQS */
 					/* forms list file */
@@ -451,11 +441,9 @@ char *forms;				/* Forms to be deleted */
  *	void udb_delnqsman():
  *	Delete an NQS manager from the NQS manager database.
  */
-void udb_delnqsman (account_uid, account_mid)
-uid_t account_uid;			/* Manager account user-id */
-Mid_t account_mid;			/* Manager account machine-id */
+void udb_delnqsman (uid_t account_uid, Mid_t account_mid)
 {
-	register struct gendescr *descr;
+	struct gendescr *descr;
 
 	seekdbb (Mgrfile, 0L);		/* Seek to the beginning of the NQS */
 					/* manager access list file */
@@ -486,8 +474,7 @@ Mid_t account_mid;			/* Manager account machine-id */
  *	Delete a queue descriptor and any associated queue-ordering
  *	or queue access file from the NQS database.
  */
-void udb_delque (queue)
-struct nqsqueue *queue;				/* Queue to be deleted */
+void udb_delque (struct nqsqueue *queue)
 {
 	char path [MAX_PATHNAME+1];
 	sprintf (path, "%s/q%08x%04x", Nqs_qorder, queue->queueno,
@@ -513,8 +500,7 @@ struct nqsqueue *queue;				/* Queue to be deleted */
  *	void udb_delquedes():
  *	Delete a pipe queue destination from the NQS database.
  */
-void udb_delquedes (map)
-struct qdestmap *map;			/* Queue/dest mapping to be deleted */
+void udb_delquedes (struct qdestmap *map)
 {
 	freedb (Qmapfile, map->mapno);
 }
@@ -526,8 +512,7 @@ struct qdestmap *map;			/* Queue/dest mapping to be deleted */
  *	void udb_delquedev():
  *	Delete a queue/device mapping from the NQS database.
  */
-void udb_delquedev (map)
-struct qdevmap *map;			/* Queue/device map to be deleted */
+void udb_delquedev (struct qdevmap *map)
 {
 	freedb (Qmapfile, map->mapno);
 }
@@ -539,8 +524,7 @@ struct qdevmap *map;			/* Queue/device map to be deleted */
  *	void udb_destination():
  *	Update the destination state stored in the NQS database.
  */
-void udb_destination (dest)
-struct pipeto *dest;			/* Pipe structure */
+void udb_destination (struct pipeto *dest)
 {
 	struct gendescr descr;
 
@@ -560,11 +544,10 @@ struct pipeto *dest;			/* Pipe structure */
  *	void udb_device():
  *	Update the device state stored in the NQS database.
  */
-void udb_device (device)
-struct device *device;
+void udb_device (struct device *device)
 {
 	struct gendescr descr;
-	register struct request *request;
+	struct request *request;
 
 	descr.v.dev.status = device->status;
 	strcpy (descr.v.dev.statmsg, device->statmsg);
@@ -705,9 +688,7 @@ void udb_netprocs()
  *	void udb_setservperf():
  *	Set server performance.
  */
-void udb_setservperf (server, performance)
-Mid_t server;
-int performance;
+void udb_setservperf (Mid_t server, int performance)
 {
     struct gendescr *descr;
     struct gendescr new_descr;
@@ -774,10 +755,9 @@ int performance;
  *
  *      Re-enable the pipe queue destination.
  */
-void udb_setservavail(server)
-Mid_t server;
+void udb_setservavail(Mid_t server)
 {
-        register struct pipeto *dest;   /* Pipe queue destination */
+        struct pipeto *dest;   /* Pipe queue destination */
 
 	dest = Pipetoset;               /* Global pipe queue destination set */
 	while (dest != (struct pipeto *) 0) {
@@ -804,16 +784,15 @@ Mid_t server;
  *	Update the access file for the specified queue
  *	in the NQS database.
  */
-void udb_qaccess (queue)
-struct nqsqueue *queue;
+void udb_qaccess (struct nqsqueue *queue)
 {
 
 	unsigned long buffer [QAFILE_CACHESIZ];		/* Output buffer */
 	char path [MAX_PATHNAME+1];
-	register int index;
-	register int fd;
-	register struct acclist *acclistp;
-	register int newversion;
+	int index;
+	int fd;
+	struct acclist *acclistp;
+	int newversion;
 	int oldversion;
 
 	oldversion = queue->q.accessversion;
@@ -879,15 +858,14 @@ struct nqsqueue *queue;
  *	Update the req ordering file for the specified queue
  *	in the NQS database.
  */
-void udb_qorder (queue)
-struct nqsqueue *queue;
+void udb_qorder (struct nqsqueue *queue)
 {
 	struct qentry buffer [QOFILE_CACHESIZ];		/* Output buffer */
 	char path [MAX_PATHNAME+1];
-	register int index;
-	register int fd;
-	register struct request *request;
-	register int newversion;
+	int index;
+	int fd;
+	struct request *request;
+	int newversion;
 	int oldversion;
 
 	oldversion = queue->q.orderversion;
@@ -981,11 +959,10 @@ struct nqsqueue *queue;
  *      void udb_quecom():
  *      Update the database for a queue complex.
  */
-void udb_quecom (qcomplex)
-struct qcomplex *qcomplex;              /* Ptr to queue complex structure */
+void udb_quecom (struct qcomplex *qcomplex)
 {
         struct gendescr descr;
-        register int    i;
+        int    i;
 
         bytezero( (char *)&descr, sizeof(struct gendescr) );
         descr.v.qcom.runlimit = qcomplex->runlimit;
@@ -1010,14 +987,13 @@ struct qcomplex *qcomplex;              /* Ptr to queue complex structure */
  *	This does NOT update the request ordering file for the queue.
  *	This function DOES clear the QUE_UPDATE bit.
  */
-void udb_queue (queue)
-struct nqsqueue *queue;
+void udb_queue (struct nqsqueue *queue)
 {
 /*
  *	Uncomment the declaration of: i, if your compiler is not capable
  *	of assigning entire structures.
  *
- *	register int i;
+ *	int i;
  */
 	struct gendescr descr;
 
@@ -1135,17 +1111,17 @@ struct nqsqueue *queue;
  *	void udb_reqpgrp():
  *	Update req process-group in a queue-ordering file.
  */
-void udb_reqpgrp (queue, req)
-struct nqsqueue *queue;			/* Queue containing the req */
-register struct request *req;		/* Request structure for req */
+void udb_reqpgrp (
+	struct nqsqueue *queue,		/* Queue containing the req */
+	struct request *req)		/* Request structure for req */
 {
 	static int all_ones = ~0;	/* Integer with all bits 1 */
 
 	char path [MAX_PATHNAME+1];	/* Name of queue-ordering file */
 	struct qentry dummy;		/* Used for address computation */
-	register long offset;
-	register int fd;
-	register struct request *walk_request;
+	long offset;
+	int fd;
+	struct request *walk_request;
 
 	/*
 	 *  Compute name of existing queue-ordering file for the specified
@@ -1214,11 +1190,10 @@ register struct request *req;		/* Request structure for req */
  *	NQS database.  Delete all other pre-existing forms from the
  *	NQS forms list.
  */
-void udb_setfor (forms)
-char *forms;				/* Forms name */
+void udb_setfor (char *forms)
 {
 	struct gendescr newdescr;
-	register struct gendescr *descr;
+	struct gendescr *descr;
 
 	seekdbb (Formsfile, 0L);	/* Seek to the beginning of the NQS */
 					/* forms list file */
@@ -1282,7 +1257,7 @@ void udb_setlogfil ()
  */
 void udb_setnqsman ()
 {
-	register struct gendescr *descr;
+	struct gendescr *descr;
 
 	seekdbb (Mgrfile, 0L);		/* Seek to the beginning of the NQS */
 					/* manager access list file */
@@ -1311,8 +1286,7 @@ void udb_setnqsman ()
  *	Update the next available batch and device request sequence number
  *	stored in the NQS database.
  */
-void udb_useqno (seqno)
-long seqno;				/* Next available sequence number */
+void udb_useqno (long seqno)
 {
 	/*
 	 *  Please read the comments in ../src/nqs_ldconf.c so that
@@ -1338,11 +1312,11 @@ long seqno;				/* Next available sequence number */
  *	Returns:
  *		Next available index in buffer.
  */
-int udb_qapack (fd, buffer, index, acclistp)
-register int fd;					/* File descr */
-register unsigned long buffer [QAFILE_CACHESIZ];	/* Output buffer */
-register int index;					/* Index into buffer */
-register struct acclist *acclistp;			/* Structure to write */
+int udb_qapack (
+	int fd,					/* File descr */
+	unsigned long buffer [QAFILE_CACHESIZ],	/* Output buffer */
+	int index,				/* Index into buffer */
+	struct acclist *acclistp)		/* Structure to write */
 {
 	int i;					/* Array index */
 	
@@ -1390,13 +1364,13 @@ register struct acclist *acclistp;			/* Structure to write */
  *	Returns:
  *		Next available index in buffer.
  */
-int udb_qopack (fd, buffer, index, request, queuetype, req_is_running)
-register int fd;				/* File descr */
-register struct qentry buffer [QOFILE_CACHESIZ];/* Output buffer */
-register int index;				/* Output buffer index */
-register struct request *request;		/* Request to write */
-int queuetype;					/* Type of containing queue */
-short req_is_running;				/* Boolean true if req is */
+int udb_qopack (
+	int fd,					/* File descr */
+	struct qentry buffer [QOFILE_CACHESIZ],	/* Output buffer */
+	int index,				/* Output buffer index */
+	struct request *request,		/* Request to write */
+	int queuetype,				/* Type of containing queue */
+	short req_is_running)			/* Boolean true if req is */
 						/* presently running */
 {
 	if (request != (struct request *) 0) {
