@@ -113,9 +113,7 @@ char *Qhold_prefix = "Qhold";
  *
  *	qhold [ -u <username> ] [-v] <request-id(s)>
  */
-main (argc, argv)
-int argc;
-char **argv;
+main (int argc, char *argv[])
 {
 
 	int n_reqs;			/* Number of reqs to hold. */
@@ -314,8 +312,7 @@ BAD SYSTEM TYPE
  *	Catch certain signals, and delete the inter-process
  *	communication file we have been using.
  */
-static void qhold_cleanup (sig)
-int sig;				/* Signal that was caught */
+static void qhold_cleanup (int sig)
 {
 	signal (sig, SIG_IGN);		/* Ignore multiple signals */
 	exiting();			/* Delete our comm. file */
@@ -328,9 +325,7 @@ int sig;				/* Signal that was caught */
  *	qhold_diaghold():
  *	Diagnose hdlreq() completion code.
  */
-static void qhold_diaghold (code, reqid)
-long code;				/* Transaction completion code */
-char *reqid;				/* Character version of request-id */
+static void qhold_diaghold (long code, char *reqid)
 {
 	switch (code) {
 	case TCML_INTERNERR:
