@@ -265,10 +265,7 @@ short export;			/* "-x" flag seen boolean */
  *
  *	Submit a batch request.
  */
-main (argc, argv, envp)
-int argc;
-char *argv[];
-char *envp[];				/* Environment */
+main (int argc, char *argv[], char *envp[])
 {
 
 	static char *reserved [] = {	/* Environment variable names */
@@ -971,9 +968,7 @@ BAD SYSTEM TYPE
  *	void bad_syntax():
  *	Display message and exit.
  */
-static void bad_syntax (flag, cmdline)
-char *flag;				/* Which flag */
-int cmdline;				/* Boolean */
+static void bad_syntax (char *flag, int cmdline)
 {
 	fprintf (stderr, "Invalid syntax following -%s flag.\n", flag);
 	if (!cmdline) showline();
@@ -987,9 +982,7 @@ int cmdline;				/* Boolean */
  *	void bad_value ():
  *	Display message and exit.
  */
-static void bad_value (flag, cmdline)
-char *flag;				/* Which flag */
-int cmdline;				/* Boolean */
+static void bad_value (char *flag, int cmdline)
 {
 	fprintf (stderr, "Invalid value following -%s flag.\n", flag);
 	if (!cmdline) showline();
@@ -1005,8 +998,7 @@ int cmdline;				/* Boolean */
  *	Upon receipt of certain signals, we are not to complete the
  *	task of submitting a request to the NQS system for execution.
  */
-static void cleanup (sig)
-int sig;			/* Signal received */
+static void cleanup (int sig)
 {
 	signal (sig, SIG_IGN);	/* Ignore multiple signals */
 	zapreq();		/* Unlink all files in the NQS new request */
@@ -1025,12 +1017,10 @@ int sig;			/* Signal received */
  *	character strings specified in the collision set.  Otherwise,
  *	zero is returned.
  */
-static int collision (target, collideset)
-char *target;				/* The target string */
-char *collideset[];			/* Set of collision strings */
+static int collision (char *target, char *collideset[])
 {
-	register int length;
-	register char *cp;
+	int length;
+	char *cp;
 
 	if ((cp = strchr (target, '=')) == (char *) 0) {
 		length = strlen (target);
@@ -1052,17 +1042,16 @@ char *collideset[];			/* Set of collision strings */
  *	Finish processing an argument.
  *	Returns a pointer (char**) to the next argument to be processed.
  */
-static char **
-docpu(argv, argument, cmdline, string, flag, seenbit, enfbit, where, maxonly)
-char *argv[];				/* Ptr to remaining args */
-char *argument;				/* First of remaining args */
-int cmdline;				/* Boolean */
-char *string;				/* For error msgs */
-char *flag;				/* For error msgs */
-long seenbit;				/* To mark "seen" in bit mask */
-long enfbit;				/* To mark "enforce" in bit mask */
-struct cpulimit *where;			/* To put into rawreq */
-int maxonly;				/* Do not accept warning limit */
+static char ** docpu(
+	char *argv[],			/* Ptr to remaining args */
+	char *argument,			/* First of remaining args */
+	int cmdline,			/* Boolean */
+	char *string,			/* For error msgs */
+	char *flag,			/* For error msgs */
+	long seenbit,			/* To mark "seen" in bit mask */
+	long enfbit,			/* To mark "enforce" in bit mask */
+	struct cpulimit *where,		/* To put into rawreq */
+	int maxonly)			/* Do not accept warning limit */
 {
 	    if (argument [3] != '\0') {
 		invalidflag (cmdline, argument);
@@ -1123,15 +1112,15 @@ int maxonly;				/* Do not accept warning limit */
  *	Returns a pointer (char**) to the next argument to be processed.
  */
 static char **
-donice(argv, argument, cmdline, string, flag, seenbit, enfbit, where)
-char *argv[];				/* Ptr to remaining args */
-char *argument;				/* First of remaining args */
-int cmdline;				/* Boolean */
-char *string;				/* For error msgs */
-char *flag;				/* For error msgs */
-long seenbit;				/* To mark "seen" in bit mask */
-long enfbit;				/* To mark "enforce" in bit mask */
-short *where;				/* To put into rawreq */
+donice(
+	char *argv[],			/* Ptr to remaining args */
+	char *argument,			/* First of remaining args */
+	int cmdline,			/* Boolean */
+	char *string,			/* For error msgs */
+	char *flag,			/* For error msgs */
+	long seenbit,			/* To mark "seen" in bit mask */
+	long enfbit,			/* To mark "enforce" in bit mask */
+	short *where)			/* To put into rawreq */
 {
 	    int negnice;
 	    int i;
@@ -1221,16 +1210,16 @@ short *where;				/* To put into rawreq */
  *	Returns a pointer (char**) to the next argument to be processed.
  */
 static char **
-doquota(argv, argument, cmdline, string, flag, seenbit, enfbit, where, maxonly)
-char *argv[];				/* Ptr to remaining args */
-char *argument;				/* First of remaining args */
-int cmdline;				/* Boolean */
-char *string;				/* For error msgs */
-char *flag;				/* For error msgs */
-long seenbit;				/* To mark "seen" in bit mask */
-long enfbit;				/* To mark "enforce" in bit mask */
-struct quotalimit *where;		/* To put into rawreq */
-int maxonly;				/* Do not accept warning limit */
+doquota(
+	char *argv[],			/* Ptr to remaining args */
+	char *argument,			/* First of remaining args */
+	int cmdline,			/* Boolean */
+	char *string,			/* For error msgs */
+	char *flag,			/* For error msgs */
+	long seenbit,			/* To mark "seen" in bit mask */
+	long enfbit,			/* To mark "enforce" in bit mask */
+	struct quotalimit *where,	/* To put into rawreq */
+	int maxonly)			/* Do not accept warning limit */
 {
 	    if (argument [3] != '\0') {
 		invalidflag (cmdline, argument);
@@ -1304,10 +1293,10 @@ static void enverror()
  *	void exceeds():
  *	Display message and exit.
  */
-static void exceeds (string, chars, cmdline)
-char *string;				/* What was exceeded */
-int chars;				/* Legal max characters */
-int cmdline;				/* Boolean */
+static void exceeds (
+	char *string,			/* What was exceeded */
+	int chars,			/* Legal max characters */
+	int cmdline)			/* Boolean */
 {
 	fprintf (stderr, "%s exceeds %d characters.\n", string, chars);
 	if (!cmdline) showline();
@@ -1321,10 +1310,7 @@ int cmdline;				/* Boolean */
  *	void flag_conflict():
  *	Display message and exit.
  */
-static void flag_conflict (flag1, flag2, cmdline)
-char *flag1;				/* First flag */
-char *flag2;				/* Second flag */
-int cmdline;				/* Boolean */
+static void flag_conflict (char *flag1, char *flag2, int cmdline)
 {
 	fprintf (stderr, "Conflict between -%s and -%s flags.\n", flag1, flag2);
 	if (!cmdline) showline();
@@ -1349,8 +1335,7 @@ int cmdline;				/* Boolean */
  *
  *		Upon reaching the end of the file, -1 is returned.
  */
-static int getscript (buffer)
-register char buffer [MAX_REQPATH+2];	/* Line buffer */
+static int getscript (char buffer[MAX_REQPATH+2])
 {
 	register int charcount;		/* Number of characters copied to */
 					/* line buffer so far. */
@@ -1424,9 +1409,7 @@ static void insmemstage()
  *	void invalidflag():
  *	Display message.  Exit if called while processing command line.
  */
-static void invalidflag (cmdline, argument)
-int cmdline;
-char *argument;
+static void invalidflag (int cmdline, char *argument)
 {
         fprintf (stderr, "Invalid argument flag: %s.\n", argument);
         if (!cmdline) showline();
@@ -1457,10 +1440,7 @@ static void notqueued()
  *
  *	Display a message and exit(1).
  */
-static void no_value (string, flag, cmdline)
-char *string;
-char *flag;
-int cmdline;
+static void no_value (char *string, char *flag, int cmdline)
 {
 	fprintf (stderr, "%s value missing after -%s flag.\n", string, flag);
 	if (!cmdline) showline();
@@ -1479,10 +1459,7 @@ int cmdline;
  *		The updated argument pointer to point at the next
  *		argument to be processed.
  */
-static char **procarg (argv, cmdline)
-register char *argv[];			/* Ptr to remaining arguments */
-int cmdline;				/* Non-zero if processing command */
-					/* line arguments */
+static char **procarg (char *argv[], int cmdline)
 {
     register char *argument;		/* Ptr to argument text */
     register int i;			/* Index and length var */
@@ -2019,6 +1996,8 @@ int cmdline;				/* Non-zero if processing command */
 	    if (!cmdline) showline();
 	    notqueued();		/* Exit */
 	case -3:
+	    fprintf (stderr, "Insufficent privilege for NMAP lookup.\n");
+	    /* fall through into next case statement ... stu */
 	case -4:
 	    fprintf (stderr, "Unable to determine machine-id for -o stdout ");
 	    fprintf (stderr, "machine name.\n");
@@ -2475,9 +2454,7 @@ int cmdline;				/* Non-zero if processing command */
  *	void scanargs():
  *	Scan arguments on shell script file line.
  */
-static void scanargs (scan, scriptargs)
-register char *scan;			/* Scan position in script line */
-char *scriptargs [MAXLINEARGS+1];	/* Argument pointer array */
+static void scanargs (char *scan, char *scriptargs[MAXLINEARGS+1])
 {
 	register arg;
 	register char ch;		/* Scan character */
@@ -2667,9 +2644,7 @@ static void spoolerror()
  *	void twice ():
  *	Display message and exit.
  */
-static void twice (flag, cmdline)
-char *flag;				/* Which flag */
-int cmdline;				/* Boolean */
+static void twice (char *flag, int cmdline)
 {
 	fprintf (stderr, "-%s appears more than once ", flag);
 	if (cmdline) {
