@@ -115,9 +115,7 @@ int monsanto_header;			/* Apparently we call some sho_ rtn */
  *	qsuspend [-a] [-u username] [-v] <request-ids>
  *	qresume [-a] [-u username] [-v] <request-ids>
  */
-main (argc, argv)
-int argc;
-char **argv;
+main (int argc, char *argv[])
 {
 
         int n_errs;                     /* Number of requests not processed. */
@@ -361,8 +359,7 @@ BAD SYSTEM TYPE
  *	Catch certain signals, and delete the inter-process
  *	communication file we have been using.
  */
-static void qsuspend_cleanup (sig)
-int sig;				/* Signal that was caught */
+static void qsuspend_cleanup (int sig)
 {
 	signal (sig, SIG_IGN);		/* Ignore multiple signals */
 	exiting();			/* Delete our comm. file */
@@ -452,9 +449,9 @@ static suspendallreq ( )
 
 }
 
-static void selrequest (qentry, que_descr) 
-struct qentry *qentry;                  /* Queue entry describing request */
-struct gendescr *que_descr;             /* Queue file queue-descriptor */
+static void selrequest ( 
+	struct qentry *qentry,          /* Queue entry describing request */
+	struct gendescr *que_descr)     /* Queue file queue-descriptor */
 {
 	struct rawreq rawreq;
 	int	cfd;
